@@ -7,51 +7,23 @@ import tensorflow as tf
 import resampy
 from scipy.io import wavfile
 import os, csv
+import librosa
 
 from dpam.dpam import *
 
-def check_wav_mp3(filename):
-    count=0
-    ext=filename[-3:]
-    if ext!='wav':
-        count+=1
-    return count
-    
-def convert_mp3_wav(filename,outfile): 
-    subprocess.call(['ffmpeg', '-i', filename,'-ar','16000',outfile])
-    
 def load_audio(path):
     
-    check=check_wav_mp3(path)
+    inputData,fs  = librosa.load(path,sr=22050)
     
-    if check!=0:
-        # not wav
-        seconds = time.time()
-        output_file = path[:-3]+'wav'
-        convert_mp3_wav(path,output_file)
-        fs, inputData  = wavfile.read(output_file)
-    else:
-        #wav
-        fs, inputData  = wavfile.read(path)
-    '''
-    if fs!=16000:
-        
-        inputData = resampy.resample(inputData, fs, 16000)
-        fs=16000
+    inputData = np.round(inputData.astype(np.float)*32768)
     
-    maximum = np.amax(inputData)
-    
-    if maximum<=1:
-        inputData = np.rint(inputData*32768)
-    '''
     shape = np.shape(inputData)
     inputData = np.reshape(inputData, [1, 1,shape[0], 1])
     
     inputData  = np.float32(inputData)
     
     return inputData
-
-
+    
 def check_length(audio1,audio2):
     
     noisy=audio1
